Post process MCMC output from sbde to create summaries of parameter and quantile estimates.
# S3 method for sbde
coef(object, burn.perc = 0.5, nmc = 200,
prob = c(.001,.01,.1,1:99,99.9,99.99,99.999)/100, ...)Extracts posterior summary of model parameters, as well as estimated quantiles. A list is returned invisibly with the following fields.
a matrix with 3 columns and nmc rows storing the posterior draws of the parameters of base distribution used in transformation
a matrix with posterior median, 2.5th and 97.5th percentiles of the parameters of the base distribution.
numeric vector of probabilities at which quantiles have been estimated. Could differ slightly from the input vector prob, by removing repetitions, as well as values that are not strictly between zero and one.
a matrix with nmc columns giving the posterior draws of the quantile values at levels given by prob.
a summary of qsamp given by the posterior median and 95 precent credible interval end points.
a vector of integers giving the indices of the mcmc samples that were used in posterior summary calculations.
a fitted model of the class sbde.
a positive fraction indicating what fraction of the saved draws are to be discarded as burn-in
integer giving the number of samples, post burn-in, to be used in Monte Carlo averaging
a numeric vector of probabiities at which quantiles are to be estimated.
not currently implemented
sbde, summary.sbde and predict.sbde for model fitting under sbde.
y <- abs(rt(n=1000, df=4))
fit <- sbde(y, blocking="all", fbase="gpd", verbose=FALSE)
coef(fit)
Run the code above in your browser using DataLab